#
# spec file for package openucx
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Use for pulling RC versions
%define version_suf %{nil}

Name:           openucx
Version:        1.18.0
Release:        3.1
Summary:        Communication layer for Message Passing (MPI)
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            http://openucx.org/

#Git-Clone:	git://github.com/openucx/ucx
#Git-Web:	https://github.com/openucx/ucx
Source:         https://github.com/openucx/ucx/releases/download/v%version%{?version_suf}/ucx-%version.tar.gz
Patch1:         openucx-s390x-support.patch
Patch2:         ucm-fix-UCX_MEM_MALLOC_RELOC.patch
Patch3:         UCT-IB-UD-Use-GRH-to-detect-address-family-on-non-Mellanox-hardware.patch
# PATCH-FIX-UPSTREAM
Patch4:         openucx-strict-headers.patch
# additional strict-header fixes
Patch5:         openucx-strict-headers-additional.patch
# PATCH-FIX-UPSTREAM
Patch6:         openucx-extern-c.patch
BuildRequires:  autoconf >= 2.63
BuildRequires:  automake >= 1.10
BuildRequires:  binutils-devel
BuildRequires:  gcc-c++
BuildRequires:  libibverbs-devel
%if 0%{?suse_version} < 1330
%ifnarch s390x
BuildRequires:  libnuma-devel
%endif
%else
BuildRequires:  libnuma-devel
%endif
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 %power64 x86_64 s390x riscv64

%description
UCX stands for Unified Communication X. UCX provides a communication
layer for Message Passing (MPI), PGAS/OpenSHMEM libraries and
RPC/data-centric applications. UCX utilizes networks such as RDMA
(InfiniBand, RoCE, etc), Cray Gemini or Aries, for inter-node
communication, or TCP. UCX supports transfer of data in either main
memory (RAM) or GPU memory (through CUDA and ROCm libraries). UCX
provides intra-node communication by using shared memory mechanisms.

%package tools
Summary:        OpenUCX utilities
Group:          System/Console

%description tools
Miscallaneous utilities for Unified Communication X.

%package -n libucm0
Summary:        Memory (un)happing hooks for Unified Communication X
Group:          System/Libraries

%description -n libucm0
libucm is a standalone non-unloadable library which installs hooks
for virtual memory changes in the current process.

%package -n libucm-devel
Summary:        Development files for Unified Communication X Memory Hooks
Group:          Development/Libraries/C and C++
Requires:       libucm0 = %version

%description -n libucm-devel
libucm is a standalone non-unloadable library which installs hooks
for virtual memory changes in the current process.

%package -n libucp0
Summary:        Infiniband Unified Communication Protocols
Group:          System/Libraries

%description -n libucp0
High-level API uses UCT framework to construct protocols commonly
found in applications (MPI, OpenSHMEM, PGAS, etc.)

%package -n libucp-devel
Summary:        Development files for Unified Communication Protocols (UC-P)
Group:          Development/Libraries/C and C++
Requires:       libucp0 = %version

%description -n libucp-devel
High-level API uses UCT framework to construct protocols commonly
found in applications (MPI, OpenSHMEM, PGAS, etc.)

%package -n libucs0
Summary:        Infiniband Unicified Communication Services
Group:          System/Libraries

%description -n libucs0
This framework provides infrastructure for component based
programming, memory management, and system utilities.

%package -n libucs-devel
Summary:        Development files for Unified Communication Services (UC-S)
Group:          Development/Libraries/C and C++
Requires:       libucs0 = %version

%description -n libucs-devel
This framework provides infrastructure for component based
programming, memory management, and system utilities.

%package -n libuct0
Summary:        Infiniband Unified Communication Transport
Group:          System/Libraries

%description -n libuct0
Low-level API that expose network operations supported by underlying
hardware.

%package -n libuct-devel
Summary:        Development files for Unified Communication Transport (UC-T)
Group:          Development/Libraries/C and C++
Requires:       libuct0 = %version

%description -n libuct-devel
Low-level API that expose network operations supported by underlying
hardware.

%prep
%setup -qn ucx-%version
%autopatch -p0

%build
autoreconf -fi
export UCX_CFLAGS="%optflags -Wno-error"
%ifarch x86_64
export UCX_CFLAGS="$UCX_CFLAGS -mno-avx"
%endif
%ifarch %ix86
export UCX_CFLAGS="$UCX_CFLAGS -mno-sse -mno-sse2"
%endif
%configure --disable-static --without-avx \
%if 0%{?suse_version} < 1330
%ifarch s390x
         --disable-numa \
%endif
%endif
         --docdir="%_docdir/%name" \
		 --disable-debug --disable-assertions \
		 --disable-params-check \
		 --with-rc --with-ud --with-dc \
                 --with-ib-hw-tm --with-dm --with-devx \
		 --with-mlx5 --with-rdmacm

# Override BASE_CFLAGS to disable Werror (boo#1121267)
make %{?_smp_mflags} V=1 BASE_CFLAGS="-g -Wall"

%post   -n libucp0 -p /sbin/ldconfig
%postun -n libucp0 -p /sbin/ldconfig
%post   -n libucs0 -p /sbin/ldconfig
%postun -n libucs0 -p /sbin/ldconfig
%post   -n libuct0 -p /sbin/ldconfig
%postun -n libuct0 -p /sbin/ldconfig
%post   -n libucm0 -p /sbin/ldconfig
%postun -n libucm0 -p /sbin/ldconfig

%install
%make_install
rm -fv "%buildroot/%_libdir"/*.la
rm -fv "%buildroot/%_libdir"/ucx/*.la
# Rename example dir for consistency with the package name
mv %buildroot/%_datadir/ucx  %buildroot/%_datadir/openucx
# io_demo should not be in %{bindir} and more likely in %{libexec}
mkdir -p %buildroot/%_libexecdir/%{name}/
mv %buildroot/%_bindir/io_demo  %buildroot/%_libexecdir/%{name}/

%files tools
%defattr(-,root,root)
%_bindir/ucx_*
%_datadir/%{name}/
%_libexecdir/%{name}
%_libdir/pkgconfig/ucx.pc
%dir %_libdir/cmake/
%_libdir/cmake/ucx/
%dir %{_sysconfdir}/ucx/
%config %{_sysconfdir}/ucx/ucx.conf
%license LICENSE
%doc NEWS

%files -n libucm0
%defattr(-,root,root)
%_libdir/libucm.so.*

%files -n libucm-devel
%defattr(-,root,root)
%_includedir/ucm/
%_libdir/libucm.so

%files -n libucp0
%defattr(-,root,root)
%_libdir/libucp.so.*

%files -n libucp-devel
%defattr(-,root,root)
%_includedir/ucp/
%_libdir/libucp.so

%files -n libucs0
%defattr(-,root,root)
%_libdir/libucs.so.*
%_libdir/libucs_signal.so.*

%files -n libucs-devel
%defattr(-,root,root)
%_includedir/ucs/
%_libdir/libucs.so
%_libdir/libucs_signal.so
%_libdir/pkgconfig/ucx-ucs.pc

%files -n libuct0
%defattr(-,root,root)
%_libdir/libuct.so.*
%dir %_libdir/ucx/
%_libdir/ucx/libuct_*.so.*
%_libdir/ucx/libucx_perftest_mad.so.*

%files -n libuct-devel
%defattr(-,root,root)
%_includedir/uct/
%_libdir/libuct.so
%dir %_libdir/ucx/
%_libdir/ucx/libuct_*.so
%_libdir/ucx/libucx_perftest_mad.so
%_libdir/pkgconfig/ucx-uct.pc
%_libdir/pkgconfig/ucx-cma.pc
%_libdir/pkgconfig/ucx-ib.pc
%_libdir/pkgconfig/ucx-ib-mlx5.pc
%_libdir/pkgconfig/ucx-rdmacm.pc

%changelog
* Fri May  2 2025 Friedrich Haubensak <hsk17@mail.de>
- Add openucx-strict-headers.patch and openucx-extern-c.patch from
  upstream and additional openucx-strict-headers-additional.patch
  to build w/ gcc-15 (boo#1241939)
* Tue Apr  1 2025 Nicolas Morey <nicolas.morey@suse.com>
- Add UCT-IB-UD-Use-GRH-to-detect-address-family-on-non-Mellanox-hardware.patch
  to fix an UD init issue on non-Mellanox RDMA HW (bsc#1240204).
* Wed Feb 19 2025 Nicolas Morey <nicolas.morey@suse.com>
- Update to ucx 1.18.0
  - UCP
  - Enabled using CUDA staging buffers for pipeline protocols by default
  - Added endpoint reconfiguration support for non-reused p2p scenarios
  - Enabled non-cacheable memory domains, activated for gdr_copy
  - Added user_data parameter to ucp_ep_query
  - Added support for host memory pipeline through CUDA buffers for rendezvous protocol
  - Added global VA infrastructure and memory region in absence of error handling
  - Made protocol performance node names more informative
  - Enforced always running on the same thread in single thread mode
  - Multiple improvements in protocols selection infrastructure
  - Added UCP_MEM_MAP_LOCK API flag to enforce locked memory mapping
  - Allowed up-to 64 endpoint lanes for systems with many transports or devices
  - Added usage tracker to worker
  - Improved various logging messages
  - Fixed stack overflow in exported rkey unpack
  - Removed extra remote-cpu overhead from protocol estimation for zcopy
  - Fixed performance estimation for rndv pipeline protocols
  - Fixed ATP sending by picking the correct lane
  - Fixed missing reg_id on memh creation
  - Fixed repeated invalidations by retaining existing access flags
  - Fixed abort reason propagation for rendezvous RTR mtype
  - Do not check transport availability if it is disabled by UCX_TLS environment variable
  - Fixed wrong flag being used for checking BCOPY capability
  - Fixed sending too many ATPs for small messages
  - Enforced 16 bits size for Active Messages identifiers
  - Fixed unnecessary status check for emulated AMO
  - Fixed more than one fragment sending in rendezvous pipeline
  - Fixed crash by using biggest max frag across all lanes
  - Fixed missing memory handle flags by copying from parent to child
  - Fixed worker interface activate count
  - Fixed flush requests by replacing ATP/flush lane map with lane indexes
  - Fixed lost uct_flags when merging memory regions
  - UCT
  - Fixed memory domain UCT flags description
  - RDMA CORE (IB, ROCE, etc.)
  - Added environment variable to manage DC initiator capacity
  - Added DC dcs_hybrid policy
  - Reduced MLX5/DV stack size consumption
  - Added ODP support for verbs and mlx5dv
  - Added support of CUDA managed memory on IB when ODP is available
  - Added support of Adaptive Routing on RoCE
  - Enabled use of implicit ODP with relaxed ordering
  - Improved GPU-Direct detection in IB transport
  - Increased DC initiator default count to 32 for performance optimization
  - Added ConnectX-8 device support with DDP
  - Added support for subnet filter list for RoCE interfaces
  - Enhanced the error message to provide more details when a connection cannot be
    established due to unreachable transports
  - Added IB MLX5 as a separate UCX module with separate RPM sub-package
  - Added initial support for GGA transport, for fast DPU memory access
  - Set IB DevX atomic mode based on device capabilities
  - Removed DC keepalive mechanism, since the keepalive is done on UCP layer
  - Optimized cross-gVMI memory registration using indirect memory keys cache
  - Improved various logging messages
  - Fixed FETCH_ADD remote access error for ODP/KSM case
  - Fixed missing conditional compilation checks for DM
  - Fixed IB MD allocation naming typo
  - Fixed invalid GIDs filter in IB
  - Fixed flags usage in MLX5 zcopy_post
  - Do not limit ODP registration retries
  - Fixed JUCX failures by considering the number of supported completion vectors
  - UCS
  - Added support for wildcards in configuration parameter names
  - Added ASAN protection to several internal data structures
  - Reduced stack usage in topology detection code
  - Improved bitmaps configuration parsing with wider bitfield
  - Added options to set topology distance between devices
  - Optimized VFS unix socket watch by using user private folder
  - Added general IP subnet matching infrastructure
  - Extend array data structure to support user-provided array copy routine
  - Improved time units description
  - Fixed a crash by using heap allocation to process expired timers in batch
  - Fixed allocation issue on memtrack dump
  - Fixed deletion of the monitored folder in VFS
  - Fixed unsafe resize for DC initiator array
  - Fixed function macro invocation to match C standard
  - Fixed calling async handler on already released resource
  - Fixed performance by setting higher bandwidth for different NUMA nodes on Grace
  - Fixed undeclared value error in timer conversion routine
  - Fixed uninitialized value access in registration cache
  - UCM
  - Extend CUDA memory hooks to include memory mapping APIs
  - Fixed race condition in parsing proc maps
  - Fixed mremap failure while parsing /proc/self/maps
  - TCP
  - Always bind endpoint to interface
  - Tools
  - Improved performance by increasing window size for put_bw and add get_bw in ucx_perftest
  - Added multi-send flag for receive operations in bandwidth benchmarks in ucx_perftest
  - Improved ucx_perftest uni-directional test with added fence
  - Detailed ucx_perftest batch section of command-line documentation
  - Fixed buffer size potential overflow in ucx_perftest
  - Fixed missing address when packing memory keys on ucx_perftest
  - Fixed memory leak for endpoint report in ucx_info
  - Fixed build without openmp in ucx_perftest
  - Fixed UCT device override on server side on ucx_perftest
  - Documentation
  - Added a section regarding adaptive routing on RoCE
  - Architecture
  - Added CPU Model for MI300A
  - Added Fujitsu ARM specific values to ucx.conf
  - Added AMD Turin support
  - Added an optimized non-temporal memory copy implementation for AMD CPU
  - Build
  - Improved compiler error reporting with added flag
  - Improved coverity script to allow faster turnaround time
  - Improved Intel Compiler detection and support
  - Fixed using correct ASAN version for running tests
  - Configuration
  - Used POSIX bourne syntax to check equality
  - Fixed build failure by using proper flags in compiler.m4
  - Fixed perftest MAD support default guessing
  - GO
  - Added multi-send flag and user memh support in request params
  - Added serialized thread mode to avoid subtle races between threads
  - Fixed make distcheck
  - Packaging
  - Improved dpkg-buildpackage sample command by explicitly adding mlx5 related arguments
- Delete UCS-TIME-Add-math.h-to-provide-INFINITY.patch which was merged upstream
- Refresh openucx-s390x-support.patch due to API changes
* Sat Sep  7 2024 Nicolas Morey <nicolas.morey@suse.com>
- Refresh openucx-s390x-support.patch to fix compilation on s390x
* Sat Jun 29 2024 Andreas Schwab <schwab@suse.de>
- Enable build on riscv64
* Wed Jun 26 2024 Nicolas Morey <nicolas.morey@suse.com>
- Update to 1.17.0
  - See NEWS for the complete CHANGELOG
- Refresh openucx-s390x-support.patch against the latest sources
- Add upstream fix UCS-TIME-Add-math.h-to-provide-INFINITY.patch
  to fix compilation on ppc64
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Oct  2 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to 1.15.0
  - UCP
  - Added 2-stage pipeline protocol in the new protocol infrastructure
  - Added reset and abort functionality of rendezvous protocols in the
    new infrastructure
  - Added zero-copy rendezvous data send protocol in the new infrastructure
  - Added support for user memory handle in the new protocol infrastructure
  - Added option to force ODP registration for certain memory types
  - Enabled lock free memory region deregistration
  - Updated allow/deny transport list feature to control auxiliary transport selection
  - Multiple performance improvements of the new protocol infrastructure
  - Multiple improvements in error and debug messages
  - Fixed assertion when sending from non-contiguous GPU buffer to managed buffer
  - Fixed the race condition on endpoint configurations
  - Fixed endpoint reconfiguration issues due to asymmetrical selection
  - Fixed endpoint reconfiguration error due to wrong locality detection
  - Fixed crash during connection manager cleanup
  - Fixed rkey index calculation for rendezvous protocol
  - Fixed rcache dump function
  - Removed logging from rkey unpack in release mode
  - Fixed dobule free of rkey in rendezvous protocol
  - Fixed rendezvous pipeline protocol error flow
  - Fixed error handling in rendezvous get zcopy protocol
  - Replay pending requests of wireup EP CM during connection establishment
    to prevent potential ordering issues and wrong configuration
  - Pass user-provided memory type to the function that checks whether the buffer
    can be sent inline or not
  - Avoid memory registration during UCP context initialization
  - Fixed CPU/device atomics selection in the new protocol infrastructure
  - Multiple fixes in the new protocol infrastructure information output
  - UCT
  - Split UCT_MD_MKEY_PACK_FLAG_INVALIDATE into two flags for RMA and AMO
  - Added put_zcopy and get_zcopy scheme support for self transport
  - Added base implementation of is_reachable_v2 API using intra/inter flag
  - Introduced MD capability for non-blocking registration memory types
  - Added check for dmabuf kernel support in ROCm memory domain
  - Fixed exported memh packing
  - Fixed an error in checking return status of multi-threaded memory
    registration function
  - RDMA CORE (IB, ROCE, etc.)
  - Added implementation of is_reachable_v2 routine to IB interface
  - Added option to control CQE zipping per CQ RX/TX direction
  - Added option to specify how DCI selects port under RoCE LAG
  - Added hw_dcs to the list of policies to select DCI by an endpoint
  - Removed implicit on-demand paging
  - Added option to set RoCE lag dct port for response under queue affinity mode
  - Improved IB memlock limit logging
  - Fixed dma-buf based memory region registration
  - Fixed memory handle data corruption when PCIe relaxed ordering is enabled
  - Fixed performance degradation when indirect atomic key is not supported
    by the hardware
  - Fixed remote access error to strict-order keys because of wrong offset
  - Added check for UAR support to memory domain opening
  - Fixed updating port counters for devx qp
  - Fixed ibv_create_cq error message on node without Infiniband
  - Fixed performance degradation due to using 2 paths on NDR400 by default
  - Removed unnecessary async lock which otherwise would block UD progress
  - UCS
  - Added ucs_string_buffer_rbrk() to split token
  - Fixed lane selection and added bandwidth estimation for Sapphire Rapids family
  - Fixed displaying wrong environment variable suggestions
  - Fixed VFS warning output
  - Fixed SEGV in ucs_debug_backtrace_next(), upon previous SEGV handling,
    due to ENOMEM situation
  - Fixed memory corruption when using UCX_MPOOL_FIFO=y
  - UCM
  - Fixed conditional jump patching
  - Fixed mremap() override
  - Tests
  - Added a rocm docker container for testing
  - Added option to send client_id in iodemo test
  - Added support for multiple connections to the same server in iodemo test
  - Added synchronization before exit to hello world examples
  - Fixed wrong usage of ep_close in examples
  - Tools
  - Added user-side memcpy option for AM benchmarks in ucx_perftest
  - Added wireshark LUA dissectors for some UCX protocols
  - Fixed memory access flags in perftest
  - Removed support for librte from perf
  - Fixed worker flush deadlock when using multiple workers in ucx_perftest
  - Build
  - Added support for binutils 2.40
  - Added versioned dependency to switch between packages with the same names
  - Added a separate xpmem deb subpackage
  - Added aarch64 support to the binary distribution pipeline
  - Removed dependency on libnuma
  - Documentation
  - Updated ucp_worker_release_address description
- Refresh openucx-s390x-support.patch against latest souces
* Tue Jul 25 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to v1.14.1
  - Fixed ROCm to prevent the locking of host pinned memory
  - Added CUDA 12 based UCX builds to the release flow
  - Increased the maximal number of endpoint configurations
  - Fixed filter for a slow-lanes in selection logic
  - Fixed TCP transport bandwidth calculation
  - Fixed device detection for ROCM
  - Fixed compatibility with CUDA 12
  - Fixed rendezvous threshold for multi-path configurations
  - Fixed error message in case of static link
  - Fixed BlueField-3 detection
  - Multiple fixes for Azure CI pipeline
* Mon Mar 20 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to v1.14.0
  - UCP
  - Added API for querying transport and device names on endpoint
  - Added API for querying datatype object
  - Added API for exporting and importing memory keys (no implementation yet)
  - Added support for non-persistent active message header
  - Added infrastructure to print protocols v2 performance
  - Multiple performance improvements for protocols v2
  - Added support for non-contiguous datatypes for rendezvous protocols v2
  - Added support for reset and abort request in protocols v2
  - Added support for user memory handles in RMA API
  - Added multi-rail support for RMA API in protocols v2
  - Added support for up to 16 different lanes per endpoint
  - Added support for dmabuf memory registration in protocols v2
  - Added strong fence mode for ucp_worker_fence() API
  - UCT
  - Added new uct_md_mem_attach() API to support exported memory handles
  - Added remote completion mode for endpoint flush (via new flag)
  - Added support for dmabuf registration
  - Added new uct_ep_connect_to_ep_v2() API
  - Added new uct_mem_reg_v2() API
  - Added new uct_md_query_v2() API
  - Added support for IPv6 loopback address in TCP transport
  - RDMA CORE (IB, ROCE, etc.)
  - Added ECE (enhanced connection establishment) support for RC and DC transports
  - Added support for hardware DCS in DC transport
  - Added UD interface and endpoint resource information to VFS
  - Added CQ creation via DEVX API
  - Removed support for accelerated IB transports over legacy experimental verbs
  - UCS
  - Added support for auto-correction of user environment variables
  - UCM
  - Implemented CUDA bistro hooks for aarch64 (to enable memory cache on this platform)
  - Added support for CUDA virtual/stream-ordered memory with cudaMallocAsync
  - Documentation
  - Added FAQ for using pkg-config tool to build applications with UCX
  - Tools
  - Added runtime library version to the 'ucx_info -v' output
  - Added support for memory types in ucx_info
  - Many bugfixes. See NEWS.
- Drop patch merged upstream:
  - UCS-DEBUG-replace-PTR-with-void.patch
  - gcc13-fix.patch
- Refresh openucx-s390x-support.patch
* Mon Mar  6 2023 Martin Liška <mliska@suse.cz>
- Add upstream gcc13-fix.patch fix.
* Mon Jan 16 2023 Andreas Schwab <schwab@suse.de>
- openucx-s390x-support.patch: fix use of clz builtin for 64-bit value
* Tue Oct  4 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update openucx-s390x-support.patch to add missing ucs_ffs32 on s390x
- Drop baselibs.conf as openucx only works on 64b systems
* Tue Sep 27 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v1.13.1 (jsc#PED-912)
  - Core
  - Added new objects to VFS: local and remote address of endpoint,
    statistics of ucp_ep_create success/failure, failed/destroyed endpoints
  - Added support for UCX static libraries
  - Added profiling for rkey management routines
  - PCIe relaxed order enabled by default for AMD CPUs
  - Fixed not deallocating memory from ucp_mem_unmap if no rcache
  - Fixed versioning infrastructure
  - Multiple code improvements: refactoring, debug prints and assertions, etc.
  - Multiple improvements in build, test and docs infrastructure
  - Added new objects to VFS (md, component, log_level, etc.)
  - Added configuration variable to specify which loadable modules are allowed
  - Added build-time configuration to disable sigaction overriding
  - UCP
  - Added API to pass pre-registered memory handle to UCP operations
  - Added implementation of AM rendezvous protocol
  - Added 2-stage pipeline rendezvous protocol for GPU
  - Added support for fragment mem_type for v1 pipeline proto, disabled by default
  - Added active message support for proto v2
  - Added UCP memory registration cache
  - Improved adaptive progress - deactivate iface when all p2p lanes are destroyed
  - Added support for user memh in proto_v1
  - Added support for selecting local address when creating a client endpoint
  - Added option to limit GPUDirectRDMA size in rendezvous protocol, UCX_RNDV_MEMTYPE_DIRECT_SIZE
  - Deprecated UCX_SOCKADDR_AUX_TLS configuration parameter
  - Resolving remote EP ID when creating local EP disabled by default
  - Added client_id to ucp_worker_create() and ucp_conn_request_query() APIs
  - Added ucp_worker_address_query() API
  - Updated ucp_ep_query() API for getting local and remote addresses
  - Added address versioning to correctly preserve wire compatibility starting from version 1.11.0
  - Added new client/server connection establishment packet header format
  - Enabled rendezvous and tag sync protocols when error handling is enabled on the endpoint
  - Added iov zcopy support to RMA operations
  - Reduced memory usage of unexpected messages by fitting receive buffer size to packet size
  - Added support for modifying UCT and UCS configs by ucp_config_modify() API
  - Optimized unpacked rkeys memory consumption
  - Added request flag to influence latency vs. bandwidth protocol
  - Reduced memory management overhead with new protocols
  - Improved performance calculations for new protocols
  - Added AMO support with GPU memory target using new protocols
  - Added put_zcopy, get_zcopy and pipeline based rendezvous in new protocols
  - Added support for user-defined alignment in Active Messages
  - Added support for offload tag sync in new protocols
  - Updated ucp_atomic_post() to use NBX flow
  - UCT
  - Introduced API uct_md_mkey_pack_v2
  - Introduced UCT iface features API
  - Introduced max_inflight_eps parameter in perf_attr API
  - Introduced UCT_SEND_FLAG_PEER_CHECK flag that forces checking connectivity to a peer
  - Introduced UCX_RCACHE_PURGE_ON_FORK to enable/disable cleaning regions when application is forking
  - Disabled PEER_FAILURE capability for XPMEM
  - Added API - uct_iface_is_reachable_v2()
  - Added IPv6 address support in TCP
  - Added latency estimation to uct_iface_estimate_perf()
  - Adjusted knem and cma overhead cost
  - Increased built-in TCP keep-alive interval to 2 seconds
  - RDMA CORE (IB, ROCE, etc.)
  - Introduced NDR autorecognition
  - Introduced CQE zipping support
  - Set the default MAX_RD_ATOMIC to maximum value supported by the hardware
  - Disabled mlx5 ifaces on verbs MD
  - Added detection of IB NDR devices
  - Added check for CQ overrun in assert mode
  - Added bitmap usage for releasing detached DCIs
  - Added configuration for requests ack frequency with DevX
  - Added remote QP info to tx error CQE traces
  - ROCM
  - Increased maximum number of HSA agents
  - UCS
  - Added topo module infrastructure
  - Added memtrack and rcache information to VFS
  - Added API for a per-process aggregate-sum statistics report
  - Added memory pool set data structure
  - Added new ptr_array API for bulk allocation
  - Added ucs_string_buffer_append_flags() for string buffer
  - Added ucs_ffs32()
  - Added ucs_vsnprintf_safe() which always adds '\0'
  - Added thread-safe put to ptr_map
  - Improved accuracy of the topology distance estimation
  - Added prints of leaked callbacks from the callback queue
  - Removed a diagnostic message when fuse thread is stopped
  - Added configurable limit for the memory consumed by rcache
  - Added configuration for VFS(FUSE) thread affinity
  - Added memory limit support to memtrack
  - Packaging
  - Added cmake config files for better integration with external cmake based projects
  - Tools
  - Added loop-back transport support in ucx_perftest
  - Split ucx_perftest into separate modules
  - Added process placement option for ucx_info
  - Extended parameters correctness check in ucx_perftest
- Backported UCS-DEBUG-replace-PTR-with-void.patch
  from upstream to fix compilation
* Thu Jan 13 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Fix UCM bistro support on non s390x archs
- Add ucm-fix-UCX_MEM_MALLOC_RELOC.patch to disable malloc relocations by default (bsc#1194369)
* Thu Sep 23 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v1.11.1 (jsc#SLE-19260)
* Wed Feb 24 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update openucx-s390x-support.patch to fix mmap syscall on s390x (bsc#1182691)
  - Core:
  - Added support for UCX monitoring using virtual file system (VFS)/FUSE
  - Added support for applications with static CUDA runtime linking
  - Added support for a configuration file
  - Updated clang format configuration
  - UCP
  - Added rendezvous API for active messages
  - Added user-defined name to context, worker, and endpoint objects
  - Added flag to silence request leak check
  - Added API for endpoint performance evaluation
  - Added API - ucp_request_query
  - Added API - ucp_lib_query
  - Added bandwidth optimizations for new protocols multi-lane
  - Added support for multi-rail over lanes with BW ratio >= 1/4
  - Added support for tracking outstanding requests and aborting those in case of connection failure
  - Refactored keep-alive protocol
  - Added device id to wireup protocol
  - Added support up to 128 transport layer resources in UCP context
  - Added support CUDA memory allocations with ucp_mem_map
  - Increased UCP_WORKER_MAX_EP_CONFIG to 64
  - Adjusted memory type zcopy threshold when UCX_ZCOPY_THRESH set
  - Refactored wireup protocols, rendezvous, get, zcopy protocols
  - Added put zcopy multi-rail
  - Improved logging for new protocols
  - Added system topology information
  - Added new protocols for eager offload protocols
  - UCT
  - Extended connection establishment API
  - Added active message AM alignment in iface params
  - Added active message short IOV API.
  - Added support for interface query by operation and memory type
  - Added API to get allocation base address and length
  - Added md_dereg_v2 API
  - UCS
  - Added log filter by source file name.
  - Added checking for last element in fraglist queue
  - Added a method to get IP address from sockaddr.
  - Added memory usage limits to registration cache
  - RDMA CORE (IB, ROCE, etc.)
  - Added report of QP info in case of completion with error
  - Refactored of FC send operations
  - Added support for  DevX unique QPN allocation
  - Optimized endpoint lookup for  DCI
  - Added support for RDMA sub-function (SF)
  - Added support for DCI via DEVX
  - Added DCI pool per LAG port
  - Added support  for RoCE IP reachability check using a subnet mask
  - Added active message short IOV for UD/DC/RC mlx, UD/RC verbs
  - Added endpoint keep alive check for UD
  - Suppressed warning if device can't be opened
  - Added support for multiple flush cancel without completion
  - Added ignore for devices with invalid GID
  - Added support for SRQ linked list reordering
  - Added flush by flow control on old devices
  - Added support for configurable rdma_resolve_addr/route timeout
  - Shared memory
  - Added active message short IOV support for posix, sysv, and self transports
  - TCP
  - Added support for peer failure in case of CONNECT_TO_EP
  - Added support for active message short IOV
  - See NEWS for a complete changelog and bug fixes
- Refresh openucx-s390x-support against latest sources
* Mon Oct  5 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v1.9.0 (jsc#SLE-15163)
  - Features:
  - Added a new class of communication APIs '*_nbx' that enable API extendability while
  - preserving ABI backward compatibility
  - Added asynchronous event support to UCT/IB/DEVX
  - Added support for latest CUDA library version
  - Added NAK-based reliability protocol for UCT/IB/UD to optimize resends
  - Added new tests for ROCm
  - Added new configuration parameters for protocol selection
  - Added performance optimization for Fujitsu A64FX with InfiniBand
  - Added performance optimization for clear cache code aarch64
  - Added support for relaxed-order PCIe access in IB RDMA transports
  - Added new TCP connection manager
  - Added support for UCT/IB PKey with partial membership in IB transports
  - Added support for RoCE LAG
  - Added support for ROCm 3.7 and above
  - Added flow control for RDMA read operations
  - Improved endpoint flush implementation for UCT/IB
  - Improved UD timer to avoid interrupting the main thread when not in use
  - Improved latency estimation for network path with CUDA
  - Improved error reporting messages
  - Improved performance in active message flow (removed malloc call)
  - Improved performance in ptr_array flow
  - Improved performance in UCT/SM progress engine flow
  - Improved I/O demo code
  - Improved rendezvous protocol for CUDA
  - Updated examples code
  - Bugfixes:
  - Fixes for most resent versions of GCC, CLANG, ARMCLANG, PGI
  - Fixes in UCT/IB for strict order keys
  - Fixes in memory barrier code for aarch64
  - Fixes in UCT/IB/DEVX for fork system call
  - Fixes in UCT/IB for rand() call in rdma-core
  - Fixed in group rescheduling for UCT/IB/DC
  - Fixes in UCT/CUDA bandwidth reporting
  - Fixes in rkey_ptr protocol
  - Fixes in lane selection for rendezvous protocol based on get-zero-copy flow
  - Fixes for ROCm build
  - Fixes for XPMEM transport
  - Fixes in closing endpoint code
  - Fixes in RDMACM code
  - Fixes in memcpy selection for AMD
  - Fixed in UCT/UD endpoint flush functionality
  - Fixes in XPMEM detection
  - Fixes in rendezvous staging protocol
  - Fixes in ROCEv1 mlx5 UDP source port configuration
  - Multiple fixes in RPM spec file
  - Multiple fixes in UCP documentation
  - Multiple fixes in socket connection manager
  - Multiple fixes in gtest
  - Multiple fixes in JAVA API implementation
- Refresh openucx-s390x-support.patch against new version
* Mon Jul 13 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v1.8.1
  - Features:
  - Added binary release pipeline in Azure CI
  - Bugfixes:
  - Multiple fixes in testing environment
  - Fixes in InfiniBand DEVX transport
  - Fixes in memory management for CUDA IPC transport
  - Fixes for binutils 2.34+
  - Fixes for AMD ROCM build environment
* Fri Jun  5 2020 Jan Engelhardt <jengelh@inai.de>
- Trim bias and filler wording from descriptions.
* Thu Jun  4 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v1.8.0
  - Features:
  - Improved detection for DEVX support
  - Improved TCP scalability
  - Added support for ROCM to perftest
  - Added support for different source and target memory types to perftest
  - Added optimized memcpy for ROCM devices
  - Added hardware tag-matching for CUDA buffers
  - Added support for CUDA and ROCM managed memories
  - Added support for client/server disconnect protocol over rdma connection manager
  - Added support for striding receive queue for hardware tag-matching
  - Added XPMEM-based rendezvous protocol for shared memory
  - Added support shared memory communication between containers on same machine
  - Added support for multi-threaded RDMA memory registration for large regions
  - Added new test cases to Azure CI
  - Added support for multiple listening transports
  - Added UCT socket-based connection manager transport
  - Updated API for UCT component management
  - Added API to retrieve the listening port
  - Added UCP active message API
  - Removed deprecated API for querying UCT memory domains
  - Refactored server/client examples
  - Added support for dlopen interception in UCM
  - Added support for PCIe atomics
  - Updated Java API: added support for most of UCP layer operations
  - Updated support for Mellanox DevX API
  - Added multiple UCT/TCP transport performance optimizations
  - Optimized memcpy() for Intel platforms
  - Added protection from non-UCX socket based app connections
  - Improved search time for PKEY object
  - Enabled gtest over IPv6 interfaces
  - Updated Mellanox and Bull device IDs
  - Added support for CUDA_VISIBLE_DEVICES
  - Increased limits for CUDA IPC registration
  - Bugfixes:
  - Multiple fixes in JUCX
  - Fixes in UCP thread safety
  - Fixes for most recent versions GCC, PGI, and ICC
  - Fixes for CPU affinity on Azure instances
  - Fixes in XPMEM support on PPC64
  - Performance fixes in CUDA IPC
  - Fixes in RDMA CM flows
  - Multiple fixes in TCP transport
  - Multiple fixes in documentation
  - Fixes in transport lane selection logic
  - Fixes in Java jar build
  - Fixes in socket connection manager for Nvidia DGX-2 platform
  - Multiple fixes in UCP, UCT, UCM libraries
  - Multiple fixes for BSD and Mac OS systems
  - Fixes for Clang compiler
  - Fix CPU optimization configuration options
  - Fix JUCX build on GPU nodes
  - Fix in Azure release pipeline flow
  - Fix in CUDA memory hooks management
  - Fix in GPU memory peer direct gtest
  - Fix in TCP connection establishment flow
  - Fix in GPU IPC check
  - Fix in CUDA Jenkins test flow
  - Multiple fixes in CUDA IPC flow
  - Fix adding missing header files
  - Fix to prevent failures in presence of VPN enabled Ethernet interfaces
- Refresh openucx-s390x-support.patch against new version
* Fri Oct  4 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure /usr/lib/ucx is owned at all times.
* Wed Sep 18 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v1.6.0
  - Features:
  - Modular architecture for UCT transports
  - ROCm transport re-design: support for managed memory, direct copy, ROCm GDR
  - Random scheduling policy for DC transport
  - Optimized out-of-box settings for multi-rail
  - Added support for OmniPath (using Verbs)
  - Support for PCI atomics with IB transports
  - Reduced UCP address size for homogeneous environments
  - Bugfixes:
  - Multiple stability and performance improvements in TCP transport
  - Multiple stability fixed in Verbs and MLX5 transports
  - Multiple stability fixes in UCM memory hooks
  - Multiple stability fixes in UGNI transport
  - RPM Spec file cleanup
  - Fixing compilation issues with most recent clang and gcc compilers
  - Fixing the wrong name of aliases
  - Fix data race in UCP wireup
  - Fix segfault when libuct.so is reloaded - issue #3558
  - Include Java sources in distribution
  - Handle EADDRNOTAVAIL in rdma_cm connection manager
  - Disable ibcm on RHEL7+ by default
  - Fix data race in UCP proxy endpoint
  - Static checker fixes
  - Fallback to ibv_create_cq() if ibv_create_cq_ex() returns ENOSYS
  - Fix malloc hooks test
  - Fix checking return status in ucp_client_server example
  - Fix gdrcopy libdir config value
  - Fix printing atomic capabilities in ucx_info
  - Fix perftest warmup iterations to be non-zero
  - Fixing default values for configure logic
  - Fix race condition updating fired_events from multiple threads
  - Fix madvise() hook
- Refresh openucx-s390x-support.patch against new version
* Wed May 15 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Disable Werror to handle boo#1121267
* Mon Feb 25 2019 nmorey <nmoreychaisemartin@suse.com>
- Update openucx-s390x-support.patch to fix support of 1.5.0 on s390x (bsc#1121267)
- Add baselibs.conf for ppc
* Fri Feb 22 2019 Martin Liška <mliska@suse.cz>
- Update to v1.5.0 (bsc#1121267)
  * Features:
  * New emulation mode enabling full UCX functionality (Atomic, Put, Get)
  * over TCP and RDMA-CORE interconnects which don't implement full RDMA semantics
  * Non-blocking API for all one-sided operations. All blocking communication APIs marked
  * as deprecated
  * New client/server connection establishment API, which allows connected handover between workers
  * Support for rdma-core direct-verbs (DEVX) and DC with mlx5 transports
  * GPU - Support for stream API and receive side pipelining
  * Malloc hooks using binary instrumentation instead of symbol override
  * Statistics for UCT tag API
  * GPU-to-Infiniband HCA affinity support based on locality/distance (PCIe)
  * Bugfixes:
  * Fix overflow in RC/DC flush operations
  * Update description in SPEC file and README
  * Fix RoCE source port for dc_mlx5 flow control
  * Improve ucx_info help message
  * Fix segfault in UCP, due to int truncation in count_one_bits()
  * Multiple other bugfixes (full list on github)
  * Tested configurations:
  * InfiniBand: MLNX_OFED 4.4-4.5, distribution inbox drivers, rdma-core
  * CUDA: gdrcopy 1.2, cuda 9.1.85
  * XPMEM: 2.6.2
  * KNEM: 1.1.2
* Tue Nov  6 2018 nmoreychaisemartin@suse.com
- Update to v1.4.0 (bsc#1103494)
  * Features:
  * Improved support for installation with latest ROCm
  * Improved support for latest rdma-core
  * Added support for CUDA IPC for intra-node GPU, CUDA memory
    allocation cache for mem-type detection, latest Mellanox
    devices, Nvidia GPU managed memory, multiple connections
    between the same pair of workers, large worker address for
    client/server connection establishment and INADDR_ANY, and
    for bitwise atomics operations.
  * Bugfixes:
  * Performance fixes for rendezvous protocol
  * Memory hook fixes
  * Clang support fixes
  * Self tl multi-rail fix
  * Thread safety fixes in IB/RDMA transport
  * Compilation fixes with upstream rdma-core
  * Multiple minor bugfixes (full list on github)
  * Segfault fix for a code generated by armclang compiler
  * UCP memory-domain index fix for zero-copy active messages
* Mon Oct 15 2018 nmoreychaisemartin@suse.com
- Update to v1.3.1 (fate#325996)
  - Prevent potential out-of-order sending in shared memory active messages
  - CUDA: Include cudamem.h in source tarball, pass cudaFree memory size
  - Registration cache: fix large range lookup, handle shmat(REMAP)/mmap(FIXED)
  - Limit IB CQE size for specific ARM boards
* Thu Aug  9 2018 nmoreychaisemartin@suse.com
- Update to v1.3.0 (bsc#1104159)
  - Added stream-based communication API to UCP
  - Added support for GPU platforms: Nvidia CUDA and AMD ROCM software stacks
  - Added API for client/server based connection establishment
  - Added support for TCP transport
  - Support for InfiniBand tag-matching offload for DC and accelerated transports
  - Multi-rail support for eager and rendezvous protocols
  - Added support for tag-matching communications with CUDA buffers
  - Added ucp_rkey_ptr() to obtain pointer for shared memory region
  - Avoid progress overhead on unused transports
  - Improved scalability of software tag-matching by using a hash table
  - Added transparent huge-pages allocator
  - Added non-blocking flush and disconnect for UCP
  - Support fixed-address memory allocation via ucp_mem_map()
  - Added ucp_tag_send_nbr() API to avoid send request allocation
  - Support global addressing in all IB transports
  - Add support for external epoll fd and edge-triggered events
  - Added registration cache for knem
  - Initial support for Java bindings
  - Multiple bugfixes (full list on github)
- Drop UCT-UD-fixed-compilation-by-gcc8.patch as it was fixed upstream
- Refresh openucx-s390x-support.patch against latest sources
* Wed Jun 13 2018 nmoreychaisemartin@suse.com
- Remove libnuma-devel on s390x for older releases
* Tue Mar 27 2018 nmoreychaisemartin@suse.com
- Add UCT-UD-fixed-compilation-by-gcc8.patch to fix compilation
  with GCC8 (bsc#1084635)
* Sat Jan 20 2018 jengelh@inai.de
- Use right documentation path.
* Fri Jan 19 2018 nmoreychaisemartin@suse.com
- Update to 1.2.2
  - Support including UCX API headers from C++ code
  - UD transport to handle unicast flood on RoCE fabric
  - Compilation fixes for gcc 7.1.1, clang 3.6, clang 5
  - When UD transport is used with RoCE, packets intended for other peers may
    arrive on different adapters (as a result of unicast flooding).
  - This change adds packet filtering based on destination GIDs. Now the packet
    is silently dropped, if its destination GID does not match the local GID.
  - Added a new device ID for InfiniBand HCA
* Fri Dec  8 2017 dimstar@opensuse.org
- Drop doxygen BuildRequires: The documentation was already not
  built with this enabled. Removing the BR causes no regression in
  the package but eliminates a build cycle
  boost -> curl -> doxygen -> openucx -> boost
* Tue Sep 19 2017 jengelh@inai.de
- Rediff openucx-s390x-support.patch as p1 to be in line with
  potential git-generated patches.
* Tue Sep 19 2017 nmoreychaisemartin@suse.com
- Switch to version 1.2.1 (Fate#324050)
  Previous 1.3+ version was based on a development branch.
  Supported platforms
  - Shared memory: KNEM, CMA, XPMEM, SYSV, Posix
  - VERBs over InfiniBand and RoCE.
    VERBS over other RDMA interconnects (iWarp, OmniPath, etc.) is available
    for community evaluation and has not been tested in context of this release
  - Cray Gemini and Aries
  - Architectures: x86_64, ARMv8 (64bit), Power64
  Features:
  - Added support for InfiniBand DC and UD transports, including accelerated verbs for Mellanox devices
  - Full support for PGAS/SHMEM interfaces, blocking and non-blocking APIs
  - Support for MPI tag matching, both in software and offload mode
  - Zero copy protocols and rendezvous, registration cache
  - Handling transport errors
  - Flow control for DC/RC
  - Dataypes support: contiguous, IOV, generic
  - Multi-threading support
  - Support for ARMv8 64bit architecture
  - A new API for efficient memory polling
  - Support for malloc-hooks and memory registration caching
* Fri Jun 30 2017 nmoreychaisemartin@suse.com
- Disable avx at configure level
* Wed Jun 28 2017 nmoreychaisemartin@suse.com
- Add openucx-s390x-support.patch to fix compilation on s390x
- Compile openucx on s390x
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Fix compilation on ppc
* Fri May 26 2017 jengelh@inai.de
- Update to snapshot 1.3+git44
  * No changelog was found
- Add -Wno-error and disable AVX/SSE as it is not guaranteed
  to exist.
* Sat Jun 18 2016 jengelh@inai.de
- Update to snapshot 0~git1727
  * New: libucm. libucm is a standalone non-unloadable library which
  installs hooks for virtual memory changes in the current process.
* Sun Sep 13 2015 jengelh@inai.de
- Update to snapshot 0~git862
  * License clarification on upstream's behalf
* Mon Jul 27 2015 jengelh@inai.de
- Initial package for build.opensuse.org (version 0~git713)
